BOWERDEPS="undefined"==typeof BOWERDEPS?{}:BOWERDEPS,function(){var n;n=function(){function n(){return["ui.router","buildbot_config","guanlecoja.ui"]}return n}(),angular.module("wsgi_dashboards",new n)}.call(this),function(){var n,r;n=function(){function n(n,r,o){var a,e,t,i,l,u,d,s;for(d=o.plugins.wsgi_dashboards,i=0,l=d.length;l>i;i++)t=d[i],u=t.name,a=t.caption,null==a&&(a=_.capitalize(u)),null==t.order&&(t.order=5),r.addGroup({name:u,caption:a,icon:t.icon,order:t.order}),e={group:u,caption:a},s={controller:"wsgiDashboardsController",templateUrl:"wsgi_dashboards/"+u+"/index.html",name:u,url:"/"+u,data:e},n.state(s)}return n}(),r=function(){function n(n,r){}return n}(),angular.module("wsgi_dashboards").config(["$stateProvider","glMenuServiceProvider","config",n]).controller("wsgiDashboardsController",["$scope","$state",r])}.call(this);